/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#ifdef USEFCNTL

#include <sys/types.h>
#include <sys/file.h>
#include <fcntl.h>

int
setsocknoblock(int fd)
{
	int flags;

	/*
	 * Enable nonblocking mode:
	 * get the file flags and
	 * set the FNDELAY flag.
	 */
	flags = fcntl(fd, F_GETFL, 0);
	if (flags != -1)
		return(fcntl(fd, F_SETFL, (flags|FNDELAY)));
	return(-1);
}

int
setsockblock(int fd)
{
	int flags;

	/*
	 * Disable nonblocking mode:
	 * get the file flags and
	 * clear the FNDELAY flag.
	 */
	flags = fcntl(fd, F_GETFL, 0);
	if (flags != -1)
		return(fcntl(fd, F_SETFL, (flags&~FNDELAY)));
	return(-1);
}

#else

#include <sys/filio.h>
#include <unistd.h>

int
setsocknoblock(int fd)
{
	int flag = 1;

	/*
	 * Enable nonblocking mode.
	 */
	return(ioctl(fd, FIONBIO, &flag));
}

int
setsockblock(int fd)
{
	int flag = 0;

	/*
	 * Disable nonblocking mode.
	 */
	return(ioctl(fd, FIONBIO, &flag));
}

#endif
